==> com.liferay.document.library.api-3.0.0-sources.jar: com/liferay/document/library/display/context/DLUIItemKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.display.context;

/**
 * @author Iván Zaera
 */
public class DLUIItemKeys {

	public static final String CANCEL_CHECKOUT =
		DLUIItemKeys.class.getName() + "#cancel-checkout";

	public static final String CHECKIN =
		DLUIItemKeys.class.getName() + "#checkin";

	public static final String CHECKOUT =
		DLUIItemKeys.class.getName() + "#checkout";

	public static final String DELETE =
		DLUIItemKeys.class.getName() + "#delete";

	public static final String DOWNLOAD =
		DLUIItemKeys.class.getName() + "#download";

	public static final String EDIT = DLUIItemKeys.class.getName() + "#edit";

	public static final String MOVE = DLUIItemKeys.class.getName() + "#move";

	public static final String MOVE_TO_THE_RECYCLE_BIN =
		DLUIItemKeys.class.getName() + "#move-to-the-recycle-bin";

	public static final String OPEN_IN_MS_OFFICE =
		DLUIItemKeys.class.getName() + "#open-in-ms-office";

	public static final String PERMISSIONS =
		DLUIItemKeys.class.getName() + "#permissions";

	public static final String VIEW_ORIGINAL_FILE =
		DLUIItemKeys.class.getName() + "#view-original-file";

}

==> com.liferay.document.library.api-6.6.2-sources.jar: com/liferay/document/library/display/context/DLUIItemKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.display.context;

/**
 * @author Iván Zaera
 * @author Mauro Mariuzzo
 */
public class DLUIItemKeys {

	public static final String CANCEL_CHECKOUT =
		DLUIItemKeys.class.getName() + "#cancel-checkout";

	public static final String CHECKIN =
		DLUIItemKeys.class.getName() + "#checkin";

	public static final String CHECKOUT =
		DLUIItemKeys.class.getName() + "#checkout";

	public static final String COMPARE_TO =
		DLUIItemKeys.class.getName() + "#compare-to";

	public static final String DELETE =
		DLUIItemKeys.class.getName() + "#delete";

	public static final String DELETE_VERSION =
		DLUIItemKeys.class.getName() + "#delete-version";

	public static final String DOWNLOAD =
		DLUIItemKeys.class.getName() + "#download";

	public static final String EDIT = DLUIItemKeys.class.getName() + "#edit";

	public static final String MOVE = DLUIItemKeys.class.getName() + "#move";

	public static final String MOVE_TO_THE_RECYCLE_BIN =
		DLUIItemKeys.class.getName() + "#move-to-the-recycle-bin";

	public static final String OPEN_IN_MS_OFFICE =
		DLUIItemKeys.class.getName() + "#open-in-ms-office";

	public static final String PERMISSIONS =
		DLUIItemKeys.class.getName() + "#permissions";

	public static final String PUBLISH =
		DLUIItemKeys.class.getName() + "#publish";

	public static final String REVERT =
		DLUIItemKeys.class.getName() + "#revert";

	public static final String VIEW_ORIGINAL_FILE =
		DLUIItemKeys.class.getName() + "#view-original-file";

	public static final String VIEW_VERSION =
		DLUIItemKeys.class.getName() + "#view-version";

}
